#!/usr/bin/env python

# Copyright CERN, 2019
# Author: <Dimitris.Lampridis@cern.ch>, <Evangelia.Gousiou@cern.ch>
# Licence: GPL v2 or later.
# Website: http://www.ohwr.org

# Import system modules
import sys
import time
import os, errno, re, sys, struct
import os.path
import traceback

# Import common modules
sys.path.append('..')
import ptsexcept
import utilities as util
import vv_skt
from ptsdefine import *


##-------------------------------------------------------------------------------------------------
##                                             main                                              --
##-------------------------------------------------------------------------------------------------

def main (card=None, default_directory='.',suite=None, serial=""):

    testname= "Test00: DUT identification"
    util.header_msg( testname, ["DUT identification"] )

    ###############################################################################
    ############################ initialization ###################################
    ###############################################################################

    util.section_msg("I2C to read RTM ID")
    test_results={}
    dut = vv_skt.SKT()
	
    ###############################################################################
    ############################ actual test ######################################
    ###############################################################################
    rtm = (dut.vv_read(CSR) >> CSR_RTM_OFS) & 0x3f
    if (rtm == 0x05):
        util.info_msg("DUT identified; detection lines read correctly: 0x%02X" % rtm)
    else:
        test_results['DUT identification']= 0
        util.err_msg("Identified wrong DUT; expected RTM ID 0x05 and received 0x%02X" % rtm)
		
    ###############################################################################
    ########################## result processing ##################################
    ###############################################################################		
    errors = util.summarise_test_results(testname, test_results)
    sys.stdout.flush()
    return 0;
        
if __name__ == '__main__' :
    main()
