#!   /usr/bin/python
#    coding: utf8

# Copyright CERN, 2014
# Author: Julian Lewis <julian.lewis@cern.ch>
#         Theodor Stana <t.stana@cern.ch>
# Licence: GPL v2 or later.
# Website: http://www.ohwr.org

import sys
import time
from ctypes import *
import os, errno, re, sys, struct
from ptsexcept import *
import socket
from socket import SHUT_RDWR
import binascii

from ptsdefine import *

import utilities as util

class SKT:

    def __init__(self, lun=None):
        """ Telnet access over a socket to ELMA I2C bus
        """
        slot = int(os.environ['ELMASLOT'])
        if type(lun) == type(slot):
            self.lun = lun
        else:
            self.lun = slot
            #raise PtsWarning("Warning: SKT __init__: Bad lun=(slot), default to %s" % slot)

        self.base = 0;
        
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.connect((os.environ['ELMAIP'], 23))
        s.recv(256)
        s.send("admin\r\n")
        s.recv(256)
        s.send(os.environ['ELMAPWD'] + "\r\n")
        s.recv(256)
        self.handle = s

        # get crate firmware version, to apply proper address in readreg/writereg
        self.handle.send("version\r\n")
        ver = self.handle.recv(256)
        pos = ver.find("Software version")
        if (pos == -1):
            util.crit_msg("Crate %s not responding as expected" % os.environ['ELMAIP'])
            #print("Unexpected response from \"version\" command, exiting...")
            #self.close()
            sys.exit(2)
        ver = float(ver[pos+17:pos+21])
        self.ver = ver


    def vv_read(self, byte_offset):
        """ Read from the application FPGA via ELMA telnet
            The byte offset will be aligned to D32
            The value will contain the 32 bit integer read
        """
        
        try:
            cm = "readreg %d %x\r\n" % (self.lun, byte_offset)
            if (self.ver < 2.27):
                rn = byte_offset/4 + 1
                cm = "readreg %d %d\r\n" % (self.lun,rn)
            #print "vv_read:Debug:cm:%s\n" % (cm)
            self.handle.send(cm)
            orig = self.handle.recv(256)
            rp = orig
            rp = rp.split(" ")[3]
            rp = rp.split("\n")[0]
            rp = int(rp,16)
        
        except Exception as e:
            msg = "vv_read: No reply from register at address 0x%03x " % (byte_offset)
            raise PtsException(msg)
        
        return rp

    def vv_init(self):
        """ Init the library, its a NO-OP in SKT class
        """
        return self.handle

    def vv_close(self):
        """ Close the socket
        """
        self.handle.shutdown(SHUT_RDWR)
        self.handle.close()
        self.handle = 0
        return 0
